@@ -49,7 +49,17 @@ _TorrentIDs = Union[str, _TorrentID, List[_TorrentID], None]
 
 def ensure_location_str(s: Union[str, pathlib.Path]) -> str:
     if isinstance(s, pathlib.Path):
+        if s.is_absolute():
+            return str(s)
+
+        warnings.warn(
+            "`pathlib.Path` will be convert to absolute path automatically, "
+            "please using a str or absolute Path to avoid unexpected path normalization\n"
+            "This warning will become error in v4",
+            DeprecationWarning,
+        )
         return str(s.absolute())
+
     return str(s)
 
 
@@ -362,7 +372,7 @@ class Client:
 
     def add_torrent(
         self,
-        torrent: Union[BinaryIO, str, bytes],
+        torrent: Union[BinaryIO, str, bytes, pathlib.Path],
         timeout: _Timeout = None,
         *,
         download_dir: str = None,
@@ -382,8 +392,9 @@ class Client:
         - ``http://``, ``https://`` or  ``magnet:`` URL
         - torrent file-like object in binary mode
         - bytes of torrent content
-        - str of base64 encoded torrent file content
-        - ``file://`` URL, deprecated
+        - ``pathlib.Path`` for local torrent file, will be read and encoded as base64.
+        - **deprecated** str of base64 encoded torrent file content
+        - **deprecated** ``file://`` URL
 
         .. NOTE::
 
